/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1/GPL 2.0/LGPL 2.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is OEone Calendar Code, released October 31st, 2001.
 *
 * The Initial Developer of the Original Code is
 * OEone Corporation.
 * Portions created by the Initial Developer are Copyright (C) 2001
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s): Garth Smedley <garths@oeone.com>
 *                 Mike Potter <mikep@oeone.com>
 *                 Karl Guertin <grayrest@grayrest.com> 
 *                 Christopher Aillon <christopher@aillon.com>
 *
 * Alternatively, the contents of this file may be used under the terms of
 * either the GNU General Public License Version 2 or later (the "GPL"), or
 * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
 * in which case the provisions of the GPL or the LGPL are applicable instead
 * of those above. If you wish to allow use of your version of this file only
 * under the terms of either the GPL or the LGPL, and not to allow others to
 * use your version of this file under the terms of the MPL, indicate your
 * decision by deleting the provisions above and replace them with the notice
 * and other provisions required by the GPL or the LGPL. If you do not delete
 * the provisions above, a recipient may use your version of this file under
 * the terms of any one of the MPL, the GPL or the LGPL.
 *
 * ***** END LICENSE BLOCK ***** */

#mini-cal {                                                           
  list-style-image: url("chrome://calendar/skin/taskbar-cal.gif");    
}                                                                     

#mini-cal:hover:active {                                              
  list-style-image: url("chrome://calendar/skin/taskbar-cal-act.gif");
}                                                                     

#mini-cal[BiffState="Alarm"] {
  list-style-image: url("chrome://calendar/skin/taskbar-calalarm.gif");
}

#mini-cal[BiffState="Alarm"]:hover:active {
  list-style-image: url("chrome://calendar/skin/taskbar-calalarm-act.gif");
}

.icon-calendar16 {
  list-style-image: url("chrome://calendar/skin/calendar-16.gif");
}


/* ::::: tools menu icons ::::: */

.icon-mail16 {
  list-style-image: url("chrome://communicator/skin/taskbar/mail-16.gif");
}

.icon-addressbook16 {
  list-style-image: url("chrome://communicator/skin/taskbar/addressbook-16.gif");
}

.icon-navigator16 {
  list-style-image: url("chrome://communicator/skin/taskbar/navigator-16.gif");
}

