#extensionManager {
  background-color: ThreeDFace;
}

/*
#extensionsView[state="extensions"] {
  background-image: url("chrome://mozapps/skin/extensions/viewWatermarkExtensions.png");
}

#extensionsView[state="themes"] {
  background-image: url("chrome://mozapps/skin/extensions/viewWatermarkThemes.png");
}
*/

/* Extension Manager Command Bar */
#commandBar {
  padding: 0px 10px 5px 10px;
}

#uninstallButton {
  margin: 0px;
  list-style-image: url("chrome://mozapps/skin/extensions/actionbuttons.png");
  -moz-image-region: rect(0px, 21px, 21px, 0px) !important;
}

#uninstallButton[disabled="true"] {
  list-style-image: url("chrome://mozapps/skin/extensions/actionbuttons.png");
  -moz-image-region: rect(21px, 21px, 42px, 0px) !important;
}

#updateButton {
  margin: 0px;
  list-style-image: url("chrome://mozapps/skin/extensions/actionbuttons.png");
  -moz-image-region: rect(0px, 42px, 21px, 21px) !important;
}

#updateButton[disabled="true"] {
  list-style-image: url("chrome://mozapps/skin/extensions/actionbuttons.png");
  -moz-image-region: rect(21px, 42px, 42px, 21px) !important;
}

#optionsButton {
  margin: 0px;
  list-style-image: url("chrome://mozapps/skin/extensions/actionbuttons.png");
  -moz-image-region: rect(0px, 84px, 21px, 63px) !important;
}

#optionsButton[disabled="true"] {
  list-style-image: url("chrome://mozapps/skin/extensions/actionbuttons.png");
  -moz-image-region: rect(21px, 84px, 42px, 63px) !important;
}

#useThemeButton {
  margin: 0px;
  list-style-image: url("chrome://mozapps/skin/extensions/actionbuttons.png");
  -moz-image-region: rect(0px, 63px, 21px, 42px) !important;
}

#useThemeButton[disabled="true"] {
  list-style-image: url("chrome://mozapps/skin/extensions/actionbuttons.png");
  -moz-image-region: rect(21px, 63px, 42px, 42px) !important;
}

#uninstallButton .button-icon, 
#updateButton .button-icon, 
#optionsButton .button-icon,
#useThemeButton .button-icon {
  margin-top: 0px !important;
  margin-bottom: 0px !important;
  -moz-margin-start: 0px !important;
  -moz-margin-end: 5px !important;
}

.commandBarSeparator {
  -moz-margin-start: 5px;
}

#getMore {
  color: #0000FF;
  text-decoration: underline !important;
  cursor: pointer;
  text-align: right;
  -moz-user-focus: normal;
}

#getMore:focus {
  -moz-outline: 1px dotted invert ! important;
}

/* Extension Buttons (Iconic buttons in each extension item) */
.extension-button {
  width: 16px;
  height: 16px;
  margin: 1px;
}

.extension-button[anonid="options-button"] {
  background-image: url("chrome://mozapps/skin/extensions/extensionOptions.png");
}

.extension-button[anonid="about-button"] {
  background-image: url("chrome://mozapps/skin/extensions/extensionAbout.png");
}

.extension-button[anonid="homepage-button"] {
  background-image: url("chrome://mozapps/skin/extensions/extensionHome.png");
}

/* Extension List Items */
extension[selected="true"] {
  background-image: url("chrome://mozapps/skin/shared/itemSelected.png");
}

extension {
  padding-top: 13px;
  padding-bottom: 13px;
  -moz-padding-start: 13px;
  -moz-padding-end: 10px;
  min-height: 25px;
  border-bottom: 1px dotted #C0C0C0;
  background-image: url("chrome://mozapps/skin/shared/itemFader.png");
}

extension[disabled="true"] {
  color: GrayText;
  background-image: none;
}

extension[disabled="true"][compatible="false"] .extension-item-description {
  color: #C77173;
}

extension[disabled="true"][selected="true"] {
  background-image: url("chrome://mozapps/skin/shared/itemSelected.png");
}

extension[disabled="true"] .extension-icon {
  opacity: 0.3;
}

.extension-item-name {
  font-weight: bold;
}

.extension-icon {
  -moz-margin-end: 10px; 
}

.previewText {
  font-size: larger;
  font-weight: bold;
  color: ThreeDShadow;
  text-align: center;
}

extension[itemType="theme"] {
  padding-top: 7px;
  padding-bottom: 7px;
  -moz-padding-start: 6px;
  -moz-padding-end: 5px;
}

extension[itemType="theme"] .extension-icon {
  -moz-margin-end: 3px;
}

.themePreviewArea {
  -moz-appearance: listbox;
  margin-top: 10px;
  margin-bottom: 5px;
  -moz-margin-start: 5px;
  -moz-margin-end: 10px;
}

